==> aws-cdk-lib-2.0.0-rc.20-sources.jar: software/amazon/awscdk/cloudassembly/schema/RuntimeInfo.java <==
package software.amazon.awscdk.cloudassembly.schema;

/**
 * (experimental) Information about the application's runtime components.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.31.0 (build 6fa403d)", date = "2021-09-01T10:26:56.117Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.cloud_assembly_schema.RuntimeInfo")
@software.amazon.jsii.Jsii.Proxy(RuntimeInfo.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface RuntimeInfo extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) The list of libraries loaded in the application, associated with their versions.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.util.Map<java.lang.String, java.lang.String> getLibraries();

    /**
     * @return a {@link Builder} of {@link RuntimeInfo}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link RuntimeInfo}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<RuntimeInfo> {
        private java.util.Map<java.lang.String, java.lang.String> libraries;

        /**
         * Sets the value of {@link RuntimeInfo#getLibraries}
         * @param libraries The list of libraries loaded in the application, associated with their versions. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder libraries(java.util.Map<java.lang.String, java.lang.String> libraries) {
            this.libraries = libraries;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link RuntimeInfo}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public RuntimeInfo build() {
            return new Jsii$Proxy(libraries);
        }
    }

    /**
     * An implementation for {@link RuntimeInfo}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements RuntimeInfo {
        private final java.util.Map<java.lang.String, java.lang.String> libraries;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.libraries = software.amazon.jsii.Kernel.get(this, "libraries", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.util.Map<java.lang.String, java.lang.String> libraries) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.libraries = java.util.Objects.requireNonNull(libraries, "libraries is required");
        }

        @Override
        public final java.util.Map<java.lang.String, java.lang.String> getLibraries() {
            return this.libraries;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("libraries", om.valueToTree(this.getLibraries()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.cloud_assembly_schema.RuntimeInfo"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            RuntimeInfo.Jsii$Proxy that = (RuntimeInfo.Jsii$Proxy) o;

            return this.libraries.equals(that.libraries);
        }

        @Override
        public final int hashCode() {
            int result = this.libraries.hashCode();
            return result;
        }
    }
}

==> aws-cdk-lib-2.10.0-sources.jar: software/amazon/awscdk/cloudassembly/schema/RuntimeInfo.java <==
package software.amazon.awscdk.cloudassembly.schema;

/**
 * Information about the application's runtime components.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.cloudassembly.schema.*;
 * RuntimeInfo runtimeInfo = RuntimeInfo.builder()
 *         .libraries(Map.of(
 *                 "librariesKey", "libraries"))
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-29T04:34:13.543Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.cloud_assembly_schema.RuntimeInfo")
@software.amazon.jsii.Jsii.Proxy(RuntimeInfo.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface RuntimeInfo extends software.amazon.jsii.JsiiSerializable {

    /**
     * The list of libraries loaded in the application, associated with their versions.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.util.Map<java.lang.String, java.lang.String> getLibraries();

    /**
     * @return a {@link Builder} of {@link RuntimeInfo}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link RuntimeInfo}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<RuntimeInfo> {
        java.util.Map<java.lang.String, java.lang.String> libraries;

        /**
         * Sets the value of {@link RuntimeInfo#getLibraries}
         * @param libraries The list of libraries loaded in the application, associated with their versions. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder libraries(java.util.Map<java.lang.String, java.lang.String> libraries) {
            this.libraries = libraries;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link RuntimeInfo}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public RuntimeInfo build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link RuntimeInfo}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements RuntimeInfo {
        private final java.util.Map<java.lang.String, java.lang.String> libraries;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.libraries = software.amazon.jsii.Kernel.get(this, "libraries", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.libraries = java.util.Objects.requireNonNull(builder.libraries, "libraries is required");
        }

        @Override
        public final java.util.Map<java.lang.String, java.lang.String> getLibraries() {
            return this.libraries;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("libraries", om.valueToTree(this.getLibraries()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.cloud_assembly_schema.RuntimeInfo"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            RuntimeInfo.Jsii$Proxy that = (RuntimeInfo.Jsii$Proxy) o;

            return this.libraries.equals(that.libraries);
        }

        @Override
        public final int hashCode() {
            int result = this.libraries.hashCode();
            return result;
        }
    }
}
